Test basics
===========

a.tape
------

.. vhs:: _tapes/a.tape
   :alt: a.tape

.. vhs:: _tapes/a.tape
   :alt: a.tape

.. vhs-inline::
   :alt: a.tape

   Type "pwd"
   Sleep 500ms
   Enter
   Sleep 5s

b.tape
------

.. vhs:: _tapes/b.tape
   :alt: b.tape

.. vhs:: _tapes/b.tape
   :alt: b.tape

.. vhs-inline::
   :alt: b.tape

   Type "echo hi"
   Sleep 500ms
   Enter
   Sleep 5s

c.tape
------

.. vhs-inline::
   :scale: 25%
   :alt: c.tape

   Type "echo ih"
   Sleep 500ms
   Enter
   Sleep 5s
